jactorch.vision.geometry
========================

.. automodule:: jactorch.vision.geometry

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      gen_voronoi
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: gen_voronoi


